@@ -13,6 +13,9 @@ from inspect import getmembers, isfunction, isclass, signature
 import sys
 from pythonjsonlogger import jsonlogger
 import datetime
+import logging
+
+circe_logger = logging.getLogger(__name__)
 
 
 def _stamp():
@@ -156,5 +159,9 @@ def do_transformations(uuid: uuid4, job_archive_path: str):
                             timeout=1,
                         )
                     except (ConnectionError, HTTPError):
-                        pass  # tant pis pour toi
+                        circe_logger.warning(
+                            "Could not reach client hook: {}".format(
+                                job_description.get("notify_hook")
+                            )
+                        )
             remove(job_archive_path)
